@@ -24,7 +24,7 @@ def format_bytes(n):
 
 usage = []
 
-for round_ in xrange(args.count):
+for round_ in range(args.count):
 
     print('Round %d/%d:' % (round_ + 1, args.count))
 
@@ -55,7 +55,7 @@ for round_ in xrange(args.count):
 
 usage.append(resource.getrusage(resource.RUSAGE_SELF))
 
-for i in xrange(len(usage) - 1):
+for i in range(len(usage) - 1):
     before = usage[i]
     after = usage[i + 1]
     print('%s (%s)' % (format_bytes(after.ru_maxrss), format_bytes(after.ru_maxrss - before.ru_maxrss)))
