@@ -5,7 +5,6 @@ from .common import TestCase, fate_suite
 
 class TestAudioFifo(TestCase):
     def test_data(self):
-
         container = av.open(fate_suite("audio-reference/chorusnoise_2ch_44kHz_s16.wav"))
         stream = container.streams.audio[0]
 
@@ -31,9 +30,15 @@ class TestAudioFifo(TestCase):
         self.assertTrue(input_[:min_len] == output[:min_len])
 
     def test_pts_simple(self):
-
         fifo = av.AudioFifo()
 
+        # ensure __repr__ does not crash
+        self.assertTrue(
+            str(fifo).startswith(
+                "<av.AudioFifo uninitialized, use fifo.write(frame), at 0x"
+            )
+        )
+
         iframe = av.AudioFrame(samples=1024)
         iframe.pts = 0
         iframe.sample_rate = 48000
@@ -41,6 +46,13 @@ class TestAudioFifo(TestCase):
 
         fifo.write(iframe)
 
+        # ensure __repr__ was updated
+        self.assertTrue(
+            str(fifo).startswith(
+                "<av.AudioFifo 1024 samples of 48000hz <av.AudioLayout 'stereo'> <av.AudioFormat s16> at 0x"
+            )
+        )
+
         oframe = fifo.read(512)
         self.assertTrue(oframe is not None)
         self.assertEqual(oframe.pts, 0)
@@ -61,7 +73,6 @@ class TestAudioFifo(TestCase):
         self.assertRaises(ValueError, fifo.write, iframe)
 
     def test_pts_complex(self):
-
         fifo = av.AudioFifo()
 
         iframe = av.AudioFrame(samples=1024)
@@ -79,7 +90,6 @@ class TestAudioFifo(TestCase):
         self.assertEqual(fifo.pts_per_sample, 2.0)
 
     def test_missing_sample_rate(self):
-
         fifo = av.AudioFifo()
 
         iframe = av.AudioFrame(samples=1024)
@@ -96,7 +106,6 @@ class TestAudioFifo(TestCase):
         self.assertEqual(oframe.time_base, iframe.time_base)
 
     def test_missing_time_base(self):
-
         fifo = av.AudioFifo()
 
         iframe = av.AudioFrame(samples=1024)
